@@ -1,10 +1,12 @@
 from lxml import etree
 
+from spei.resources import Orden
+
 SOAP_NS = 'http://schemas.xmlsoap.org/soap/envelope/'
 PRAXIS_NS = 'http://www.praxis.com.mx/'
 
 
-class OrdenPago(object):
+class OrdenPagoElement(object):
     def __new__(cls, element):
         ordenpago = etree.Element(etree.QName(PRAXIS_NS, 'ordenpago'))
         mensaje = etree.tostring(
@@ -16,14 +18,14 @@ class OrdenPago(object):
         return ordenpago
 
 
-class Body(object):
+class BodyElement(object):
     def __new__(cls, orden_pago):
         body = etree.Element(etree.QName(SOAP_NS, 'Body'))
         body.append(orden_pago)
         return body
 
 
-class Envelope(object):
+class EnvelopeElement(object):
     def __new__(cls, body):
         namespaces_uris = {
             'soapenv': SOAP_NS,
@@ -38,8 +40,8 @@ class Envelope(object):
 
 
 class OrdenRequest(object):
-    def __new__(cls, mensaje, as_string=True):
-        envelope = Envelope(Body(OrdenPago(mensaje.build_xml())))
+    def __new__(cls, mensaje: Orden, as_string=True):
+        envelope = EnvelopeElement(BodyElement(OrdenPagoElement(mensaje.build_xml())))
         if not as_string:
             return envelope
         return etree.tostring(envelope, xml_declaration=True)
